using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CollectibleGenerator : MonoBehaviour
{
    public GameObject gearPrefab;
    private const int NO_PREFERENCES = 2;

    private List<GameObject> collectibles = new List<GameObject>();

    public void SpawnCollectibles()
    {
        GameObject[] rows = GameObject.FindGameObjectsWithTag("RowCollectible");
        foreach (GameObject row in rows)
        {
            print(row.transform.parent.transform.parent.transform.parent.name);
            List<Transform> spawnSlots = new List<Transform>();

            foreach (Transform child in row.transform)
            {
                if (child.CompareTag("CollectibleSpawnableSlot"))
                {
                    spawnSlots.Add(child);
                }
            }

            if (spawnSlots.Count > 0)
            {
                int preferenceCode = PlayerPrefs.HasKey("Collectible Preferences") ? (int)PlayerPrefs.GetFloat("Collectible Preferences") : NO_PREFERENCES;
                Transform chosenSlot = SelectSlotWithPreference(spawnSlots, preferenceCode);

                float spawningHeightRange = PlayerPrefs.HasKey("Collectible Height") ? PlayerPrefs.GetFloat("Collectible Height") / 100 : 0f;
                float randomHeight = Random.Range(0, spawningHeightRange);
                Vector3 spawnPosition = new Vector3(chosenSlot.position.x, chosenSlot.position.y + randomHeight, chosenSlot.position.z);

                GameObject collectible = Instantiate(gearPrefab, spawnPosition, gearPrefab.transform.rotation);
                collectible.transform.SetParent(chosenSlot, true);
                collectibles.Add(collectible);
            }
        }

        UIScoreController uiScoreController = FindAnyObjectByType<UIScoreController>();
        uiScoreController.SetCurrentCount(0);
        uiScoreController.SetTotalCount(collectibles.Count);
        LogManager.Instance.RegisterTotalCollectible(collectibles.Count);
    }

    private Transform SelectSlotWithPreference(List<Transform> slots, int preferenceCode)
    {
        slots.Sort((a, b) => a.position.x.CompareTo(b.position.x)); 

        float[] probabilities;

        switch (preferenceCode)
        {
            case 1:
                probabilities = new float[] { 0.6f, 0.25f, 0.15f }; // Favor 0 slot
                break;
            case 2:
                probabilities = new float[] { 0.33f, 0.33f, 0.34f }; // No favor
                break;
            case 3:
                probabilities = new float[] { 0.15f, 0.25f, 0.6f }; // Favor 2 slot
                break;
            default:
                probabilities = new float[] { 0.33f, 0.33f, 0.34f }; // Security of all distribution proba
                break;
        }

        float randomValue = Random.value;
        float cumulativeProbability = 0f;

        for (int i = 0; i < slots.Count; i++)
        {
            cumulativeProbability += probabilities[i];
            if (randomValue <= cumulativeProbability)
                return slots[i];
        }

        return slots[2]; // Security if random.value == 1
    }


}
