import socket
import tkinter as tk

WINDOW_SIZE = 400
CENTER_CANVAS = WINDOW_SIZE // 2
MIN_BOUND = 15
MAX_BOUND = 65

UDP_IP = "127.0.0.1"
UDP_PORT = 5000
sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

REFRESH_RATE = 100

mouse_x = 0
mouse_y = 0
y_theta = 0

is_tracking = False

def aggregate_values_to_string(x, y, z, x_theta, y_theta, z_theta):
    return f"{x},{y},{z},{x_theta},{y_theta},{z_theta}"

def update_position():
    global mouse_x, mouse_y, y_theta, is_tracking        

    x = scale_value(mouse_x - CENTER_CANVAS)
    y = scale_value(CENTER_CANVAS - mouse_y)
    z = 0
    x_theta = 0
    z_theta = 0

    if (is_tracking != True):
        x = scale_value(0)
        y = scale_value(0)
        z = 0


    data = aggregate_values_to_string(x, y, z, x_theta, y_theta, z_theta)
    sock.sendto(data.encode(), (UDP_IP, UDP_PORT))
    print("Sent:", data)

    root.after(REFRESH_RATE, update_position)  

def scale_value(value, min_source=-CENTER_CANVAS, max_source=CENTER_CANVAS, min_target=MIN_BOUND, max_target=MAX_BOUND):
    return min_target + (value - min_source) * (max_target - min_target) / (max_source - min_source)


def track_mouse(event):
    global mouse_x, mouse_y
    mouse_x = event.x
    mouse_y = event.y

def adjust_rotation(event):
    global y_theta
    if event.delta > 0: 
        y_theta += 5
    else:  
        y_theta -= 5 
    print(f"Rotation Angle (Y): {y_theta}°")

def draw_center_and_arrows(canvas):
    CIRCLE_RADIUS = 20
    canvas.create_oval(CENTER_CANVAS - CIRCLE_RADIUS, CENTER_CANVAS - CIRCLE_RADIUS, 
                       CENTER_CANVAS + CIRCLE_RADIUS, CENTER_CANVAS + CIRCLE_RADIUS, fill="black")

    ARROW_MARGIN = 30
    ARROW_LENGTH = 150
    canvas.create_line(CENTER_CANVAS, CENTER_CANVAS - ARROW_MARGIN, CENTER_CANVAS, CENTER_CANVAS - ARROW_LENGTH, arrow=tk.LAST, width=2) 
    canvas.create_line(CENTER_CANVAS + ARROW_MARGIN, CENTER_CANVAS, CENTER_CANVAS + ARROW_LENGTH, CENTER_CANVAS, arrow=tk.LAST, width=2) 
    canvas.create_line(CENTER_CANVAS, CENTER_CANVAS + ARROW_MARGIN, CENTER_CANVAS, CENTER_CANVAS + ARROW_LENGTH, arrow=tk.LAST, width=2) 
    canvas.create_line(CENTER_CANVAS - ARROW_MARGIN, CENTER_CANVAS, CENTER_CANVAS - ARROW_LENGTH, CENTER_CANVAS, arrow=tk.LAST, width=2)

def disable_tracking(event):
    global is_tracking
    is_tracking = False

def enable_tracking(event):
    global is_tracking
    is_tracking = True

def main():
    global root
    root = tk.Tk()
    root.title("UDP Sender")
    root.geometry(f"{WINDOW_SIZE}x{WINDOW_SIZE}")
    root.resizable(False, False)
    
    canvas = tk.Canvas(root, width=WINDOW_SIZE, height=WINDOW_SIZE, bg="white")
    canvas.pack()
    
    draw_center_and_arrows(canvas)

    root.bind('<Motion>', track_mouse)
    root.bind("<MouseWheel>", adjust_rotation)
    root.bind("<Enter>", enable_tracking)
    root.bind("<Leave>", disable_tracking)

    update_position()

    root.mainloop()

if __name__ == "__main__":
    main()
