import socket
import tkinter as tk

# Window Configuration
WINDOW_SIZE = 400
CENTER_X = WINDOW_SIZE // 2
CENTER_Y = WINDOW_SIZE // 2

# UDP Configuration
UDP_IP = "127.0.0.1"
UDP_PORT = 5000
sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

# Rotation angle
y_theta = 0

def aggregate_values_to_string(x, y, z, x_theta, y_theta, z_theta):
    return f"{x},{y},{z},{x_theta},{y_theta},{z_theta}"

def send_mouse_position(event):
    global y_theta
    x = event.x - CENTER_X
    y = event.y - CENTER_Y
    z = 0
    x_theta = 0
    z_theta = 0
    
    data = aggregate_values_to_string(x, y, z, x_theta, y_theta, z_theta)
    sock.sendto(data.encode(), (UDP_IP, UDP_PORT))
    print("Sent:", data)

def adjust_rotation(event):
    global y_theta
    if event.delta > 0: 
        y_theta += 5
    else:  
        y_theta -= 5 
    print(f"Rotation Angle (Y): {y_theta}°")

def draw_center_and_arrows(canvas):
    CIRCLE_RADIUS = 20
    # Draw central circle
    canvas.create_oval(CENTER_X - CIRCLE_RADIUS, CENTER_Y - CIRCLE_RADIUS, CENTER_X + CIRCLE_RADIUS, CENTER_Y + CIRCLE_RADIUS, fill="black")
    
    # Draw arrows
    ARROW_MARGIN = 30
    ARROW_LENGTH = 150
    canvas.create_line(CENTER_X, CENTER_Y - ARROW_MARGIN, CENTER_X, CENTER_Y - ARROW_LENGTH, arrow=tk.LAST, width=2)  # Up
    canvas.create_line(CENTER_X + ARROW_MARGIN, CENTER_Y, CENTER_X + ARROW_LENGTH, CENTER_Y, arrow=tk.LAST, width=2)  # Right
    canvas.create_line(CENTER_X, CENTER_Y + ARROW_MARGIN, CENTER_X, CENTER_Y + ARROW_LENGTH, arrow=tk.LAST, width=2)  # Down
    canvas.create_line(CENTER_X - ARROW_MARGIN, CENTER_Y, CENTER_X - ARROW_LENGTH, CENTER_Y, arrow=tk.LAST, width=2)  # Left

def main():
    root = tk.Tk()
    root.title("Mouse Tracker")
    root.geometry(f"{WINDOW_SIZE}x{WINDOW_SIZE}")
    root.resizable(False, False)
    
    canvas = tk.Canvas(root, width=WINDOW_SIZE, height=WINDOW_SIZE, bg="white")
    canvas.pack()
    
    draw_center_and_arrows(canvas)
    
    # Bind mouse movement event
    root.bind('<Motion>', send_mouse_position)
    # Bind mouse wheel event
    root.bind("<MouseWheel>", adjust_rotation)
    
    root.mainloop()

if __name__ == "__main__":
    main()
